' Filename: beamCenterLines2Group.BAS
'
' Author: Ryan Blelloch - ATA Engineering
' Support: kurt.knutson@ata-e.com
'
' Description: Allows user to select solids and create centerline curves
' new Femap 11.4.0 API function feSolidExtractCenterlines(). The new curves
' created will be added to a newly generated group called
' "Curves Generated By feSolidExtractCenterlines"
'
' Date Modified: 20170726
'
'
'
'Copyright (c) <2017> <ATA Engineering, Inc.>
'
'Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
'associated documentation files (the "Software") to use, copy, modify, merge, and/or distribute
'royalty-free copies of the Software, and to permit persons to whom the Software is furnished
'to do so, subject to the following conditions:
'The above copyright notice and this permission notice shall be included in all copies or
'substantial portions of the Software.
'THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
'INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
'FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
'IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
'WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
'OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Sub Main

	Dim App As femap.model
	Set App = feFemap()

	Dim solidSet As femap.Set
	Set solidSet = App.feSet

	Dim centerlinesSolid As femap.Solid
	Set centerlinesSolid = App.feSolid

	Dim curveGroup As femap.Group
	Set curveGroup = App.feGroup

	Dim curveSetOld As femap.Set
	Set curveSetOld = App.feSet

	Dim curveSetNew As femap.Set
	Set curveSetNew = App.feSet

	Dim tubular As Boolean

	'Ask user for solid to create center beam lines
	rc =solidSet.Select(FT_SOLID, True, "Select solid(s) to extract centerlines in")
	'rc = centerlinesSolid.SelectID( "Choose beam solid to create center curves")
	If( rc <> FE_OK Or solidSet.Count < 0 ) Then
		Exit Sub
	End If

	'User prompt to ask whether or not solids are tubular
	Begin Dialog UserDialog 180,105,"Solids Tubular?" ' %GRID:10,7,1,1
		GroupBox 10,7,160,63,"Only Tubular Solids",.GroupBox_tube
		OptionGroup .Group_tubular
			OptionButton 20,21,100,21,"Yes",.OptionButton_y
			OptionButton 20,42,60,21,"No",.OptionButton_n
		OKButton 10,77,70,21
		CancelButton 100,77,70,21
	End Dialog
	Dim dlg As UserDialog
	rc = Dialog (dlg)

	'If user did not press okay on prompt, exit macro
	If( rc <> FE_OK ) Then
		Exit Sub
	End If

	If(dlg.Group_tubular = 0) Then
		tubular = True
	Else
		tubular = False
	End If

	'Get all curves from before API call
	curveSetOld.Clear
	curveSetOld.AddAll(FT_CURVE)

	'Perform center beam line creation
	rc = App.feSolidExtractCenterlines( solidSet.ID, -1, tubular )

	If( rc <> FE_OK ) Then
		App.feAppMessage(FCM_ERROR, "feSolidExtractCenterlines ran unsuccessfully")
	Else
		'Get all curves after API call
		curveSetNew.Clear
		curveSetNew.AddAll(FT_CURVE)
		'remove old curves to get newly generated curves
		curveSetNew.RemoveSet(curveSetOld.ID)

		'Create group of curves created by API call
		curveGroup.ID = curveGroup.NextEmptyID
		curveGroup.SetAdd(FT_CURVE, curveSetNew.ID )
		curveGroup.title = "Curves Generated By feSolidExtractCenterlines"
		curveGroup.Put(curveGroup.ID)
	End If

End Sub
